Details on bottle contents and more from GD-BMP experiment.
data("UQGDSetup")A data frame with 9 observations on the following variables.
ididentification code, a unique value for each bottle in the dataset. A factor.
descripdescription of substrate, a factor with levels Inoculum, Cellulose, Substrate C.
m.inocmass of inoculum added to the bottle at the start in g. Numeric.
m.submass of substrate added to the bottle at the start in g. Numeric.
m.tottotal mass added to the bottle at the start in g. Numeric.
m.sub.vsmass of volatile solids (VS) of substrate added to the bottle at the start in g. Numeric.
vol.hsbottle headspace in mL. Numeric.
isrVS-based inoculum-to-substrate ratio.
These data are meant to be example data for calcBgGD, for gas density-based determination of biogas production (GD-BMP).
Reactors were glass serum bottles with butyl rubber septa.
Data in UQGDBiogas are from the same bottles.