Usage
mass2vol(mass, xCH4, temp, pres = 1, unit.pres = "atm", unit.temp = "C", pres.std = NULL,
temp.std = NULL, value = "CH4", headspace = NULL, headcomp = "N2")Arguments
mass
reactor mass loss in g. A numeric vector.
xCH4
mole fraction of methane in biogas (dry, methane + carbon dioxide only). A numeric vector.
temp
the temperature of biogas as it exited the reactor. A length-one numeric vector.
Degrees Celcius by default (see unit.temp argument).
pres
the pressure of biogas as it exited the reactor. A length-one numeric vector.
Atmospheres (atm) by default (see unit.pres argument).
unit.pres
pressure units for pres and pres.std arguments.
Options are "atm" (the default), "Pa", "kPa", "hPa", and "bar".
unit.temp
temperature units for temp and temp.std arguments.
Options are "C" (degrees Celcius, the default), "F", and "K".
pres.std
standard pressure for presentation of biogas and methane results.
Default value is 1.0 atm.
Length one numeric vector.
temp.std
standard temperature for presentation of biogas and methane results.
Default value is 0 degrees C.
value
what should be returned?
Default is "CH4", which returns methane volume in mL.
"all" returns biogas, methane, and carbon dioxide volumes.
headspace
(optional) reactor headspace volume in mL.
Used to correct for effect of initial reactor headspace on mass loss.
A numeric vector.
headcomp
(optional) composition of the initial reactor headspace.
Only required if headspace argument is specified.
Currently, the only option is "N2" for dinitrogen gas.
Use of any other value will be ignored with a warnin